local lib_check = true
--[[
	lib_check is true if the DefaultUI is loaded (as detected by known methods)
	
	if there is no LME environment, the user must be running the DefaultUI
		As far as we can guess
	if there is an LME environment, then
		if the current if is vo-if, this is the default ui
		if the current if is MultiUI then
			if the registered IF is DefaultUI, we're still good
			if the registered IF is not, then
				TODO! MultiUI api to allow compatibility-named objects?
		if the current if is NOT either, then
			Unable to check for compatibility because API might not exist
	
	if the conditions fail, lib_check is false.
	the UI component of buddyCount will not generate.
	you can still use the /buddycount command.
]]--


if type(lib) == "table" and lib[0] == "LME" then
	if lib.is_exist("rad_hitflash") == false then
		lib.register("plugins/hitflash/hitflash.ini")
		if lib.get_gstate().newstate == "NO" then
			return
		end
	end
	
	if not lib.is_ready("rad_hitflash") then
		return
	end
	
	local cur_if = lib.get_gstate().ifmgr
	if cur_if == "vo-if" then
		--defaultUI is loaded, lib_check remains true
	elseif cur_if == "MultiUI" then
		local reg_if = lib.execute("MultiUI", "6", "get_interface")
		if reg_if == "DefaultUI" then
			--defaultUI is loaded, lib_check remains true
		else
			--incompatible UI is loaded and MultiUI API doesn't exist to try compatibility, lib_check sets false
			lib_check = false
			lib.log_error("Hitflash isn't patched for this UI! Check for an update.")
		end
	else
		--incompatible UI manager is loaded, lib_check is false
		lib_check = false
		lib.log_error("Hitflash isn't patched for this UI manager!")
	end
end



local InitImgForHitFlash
function InitImgForHitFlash()
	HUD.blood_flash.IMAGE = "plugins/hitflash/radial.png"
end

if lib_check then
	RegisterEvent(InitImgForHitFlash, "PLAYER_ENTERED_GAME") --in case the pilot logged off or reloaded in-space
	RegisterEvent(InitImgForHitFlash, "LEAVING_STATION") --when it should normally be applied
end